@@ -31,9 +31,10 @@
 #import <objc/objc.h>
 #import	<Foundation/NSZone.h>
 
-#ifndef	GS_WITH_GC
-#define	GS_WITH_GC	0
+#ifdef	GS_WITH_GC
+#undef  GS_WITH_GC
 #endif
+#define	GS_WITH_GC	0
 
 #import	<GNUstepBase/GNUstep.h>
 
